From: "Paul E. McKenney" <paul...@linux.vnet.ibm.com>

This commit makes the torture scripts a bit more RCU-independent.

Signed-off-by: Paul E. McKenney <paul...@linux.vnet.ibm.com>
---
 tools/testing/selftests/rcutorture/bin/functions.sh | 6 +++---
 tools/testing/selftests/rcutorture/bin/kvm.sh       | 4 ++--
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/tools/testing/selftests/rcutorture/bin/kvm.sh 
b/tools/testing/selftests/rcutorture/bin/kvm.sh
index 2f9605ed5b58..1a4a68c76914 100644
--- a/tools/testing/selftests/rcutorture/bin/kvm.sh
+++ b/tools/testing/selftests/rcutorture/bin/kvm.sh
@@ -128,7 +128,7 @@ do
                ;;
        --mac)
                checkarg --mac "(MAC address)" $# "$2" 
'^\([0-9a-fA-F]\{2\}:\)\{5\}[0-9a-fA-F]\{2\}$' error
-               RCU_QEMU_MAC=$2; export RCU_QEMU_MAC
+               TORTURE_QEMU_MAC=$2; export TORTURE_QEMU_MAC
                shift
                ;;
        --no-initrd)
@@ -380,7 +380,7 @@ then
        echo RCU_QEMU_CMD="$RCU_QEMU_CMD; export RCU_QEMU_CMD"
        echo TORTURE_QEMU_INTERACTIVE="$TORTURE_QEMU_INTERACTIVE;
                export TORTURE_QEMU_INTERACTIVE"
-       echo RCU_QEMU_MAC="$RCU_QEMU_MAC; export RCU_QEMU_MAC"
+       echo TORTURE_QEMU_MAC="$TORTURE_QEMU_MAC; export TORTURE_QEMU_MAC"
        echo "mkdir -p "$resdir" || :"
        echo "mkdir $resdir/$ds"
        cat $T/script
diff --git a/tools/testing/selftests/rcutorture/bin/functions.sh 
b/tools/testing/selftests/rcutorture/bin/functions.sh
index 623939cf814e..41fb52b805e4 100644
--- a/tools/testing/selftests/rcutorture/bin/functions.sh
+++ b/tools/testing/selftests/rcutorture/bin/functions.sh
@@ -124,7 +124,7 @@ identify_qemu_append () {
 
 # identify_qemu_args qemu-cmd serial-file
 #
 # Output arguments for qemu arguments based on the RCU_QEMU_MAC
 # and TORTURE_QEMU_INTERACTIVE environment variables.
 identify_qemu_args () {
        case "$1" in
@@ -133,9 +133,9 @@ identify_qemu_args () {
        qemu-system-ppc64)
                echo -enable-kvm -M pseries -cpu POWER7 -nodefaults
                echo -device spapr-vscsi
-               if test -n "$TORTURE_QEMU_INTERACTIVE" -a -n "$RCU_QEMU_MAC"
+               if test -n "$TORTURE_QEMU_INTERACTIVE" -a -n "$TORTURE_QEMU_MAC"
                then
-                       echo -device spapr-vlan,netdev=net0,mac=$RCU_QEMU_MAC
+                       echo -device 
spapr-vlan,netdev=net0,mac=$TORTURE_QEMU_MAC
                        echo -netdev bridge,br=br0,id=net0
                elif test -n "$TORTURE_QEMU_INTERACTIVE"
@@ -124,7 +124,7 @@ identify_qemu_append () {
 # identify_qemu_args qemu-cmd serial-file
 #
-# Output arguments for qemu arguments based on the RCU_QEMU_MAC
+# Output arguments for qemu arguments based on the TORTURE_QEMU_MAC
 # and TORTURE_QEMU_INTERACTIVE environment variables.
 identify_qemu_args () {
                then
-- 
1.8.1.5

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to